@@ -5,6 +5,7 @@ from FNLP.Regex import ReWords
 
 
 """ 
+move to engine
 - input: Takes in two lists to match
 - output: ( Overall_Score, { matched_term: count } 
 """
@@ -157,6 +158,37 @@ def to_words_v1(content: str):
     newS = Utils.remove_empty_strings(s)
     return newS
 
+def to_words_v2(content: str):
+    content = Utils.remove_special_characters(content)
+    s = content.split(" ")
+    newS = Utils.remove_empty_strings(s)
+    return newS
+
+def to_words_v3(content: str, removeStopWords=False):
+    content = Utils.remove_special_characters(content)
+    s = content.split(" ")
+    newS = Utils.remove_empty_strings(s)
+    if removeStopWords:
+        noStopNewS = []
+        for item in newS:
+            if item in Constants.STOP_WORDS:
+                continue
+            noStopNewS.append(item)
+        return noStopNewS
+    else:
+        return newS
+
+def to_words_v3_include_stop_list(content: str):
+    content = Utils.remove_special_characters(content)
+    s = content.split(" ")
+    newS = Utils.remove_empty_strings(s)
+    noStopNewS = []
+    for item in newS:
+        if item in Constants.STOP_WORDS:
+            continue
+        noStopNewS.append(item)
+    return newS, noStopNewS
+
 def to_bi_grams_v2(tokens):
     """ PUBLIC HELPER """
     return to_x_grams(tokens, 2)
@@ -198,6 +230,18 @@ def combine_words(*words):
         return temp_word.strip()
     return str(words).strip()
 
+def is_word(word:str) -> bool:
+    for char in word:
+        if not Character.is_in_alphabet(char):
+            return False
+    return True
+
+def is_potentially_a_word(word:str) -> bool:
+    r = False
+    for char in word:
+        if Character.is_in_alphabet(char):
+            r = True
+    return r
 def remove_ing(word):
     if word.endswith("ing"):
         return word[:-3]
